@@ -2,5 +2,5 @@
 import sys
 from pathlib import Path
 sys.path.append(str(Path(__file__).resolve().parent))
-from mep_tools/connectors import *
-from mep_tools/leads import *
+from connectors import *
+from leads import *
